pub struct AccountLinkEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: Option<String>,
pub link: Box<LinkContent>,
}Expand description
AccountLinkEvent : Event object for when a user has linked their LINE account with a provider’s service account. You can reply to account link events.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: Option<String>Reply token used to send reply message to this event. This property won’t be included if linking the account has failed.
link: Box<LinkContent>Implementations
Sourceimpl AccountLinkEvent
impl AccountLinkEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
link: LinkContent,
) -> AccountLinkEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, link: LinkContent, ) -> AccountLinkEvent
Event object for when a user has linked their LINE account with a provider’s service account. You can reply to account link events.