Module activated_event

Module activated_event 

Structs

ActivatedEvent
ActivatedEvent : This event indicates that the module channel has been switched to Active Channel by calling the Acquire Control API. Sent to the webhook URL server of the module channel.