pub struct BeaconEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
pub beacon: Box<BeaconContent>,
}Expand description
BeaconEvent : Event object for when a user enters the range of a LINE Beacon. You can reply to beacon events.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
beacon: Box<BeaconContent>Implementations
Sourceimpl BeaconEvent
impl BeaconEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
reply_token: String,
beacon: BeaconContent,
) -> BeaconEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, reply_token: String, beacon: BeaconContent, ) -> BeaconEvent
Event object for when a user enters the range of a LINE Beacon. You can reply to beacon events.