pub struct CallbackRequest {
pub destination: String,
pub events: Vec<Event>,
}Expand description
CallbackRequest : The request body contains a JSON object with the user ID of a bot that should receive webhook events and an array of webhook event objects.
Fields
destination: StringUser ID of a bot that should receive webhook events. The user ID value is a string that matches the regular expression, U[0-9a-f]{32}.
events: Vec<Event>Array of webhook event objects. The LINE Platform may send an empty array that doesn’t include a webhook event object to confirm communication.
Implementations