pub struct DeactivatedEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
}Expand description
DeactivatedEvent : This event indicates that the module channel has been switched to Standby Channel by calling Acquire Control API or Release Control API. Sent to the webhook URL server of the module channel.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>Implementations
Sourceimpl DeactivatedEvent
impl DeactivatedEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
) -> DeactivatedEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, ) -> DeactivatedEvent
This event indicates that the module channel has been switched to Standby Channel by calling Acquire Control API or Release Control API. Sent to the webhook URL server of the module channel.