pub struct FollowEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
pub follow: Box<FollowDetail>,
}Expand description
FollowEvent : Event object for when your LINE Official Account is added as a friend (or unblocked). You can reply to follow events.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
follow: Box<FollowDetail>Implementations
Sourceimpl FollowEvent
impl FollowEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
reply_token: String,
follow: FollowDetail,
) -> FollowEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, reply_token: String, follow: FollowDetail, ) -> FollowEvent
Event object for when your LINE Official Account is added as a friend (or unblocked). You can reply to follow events.