pub struct ImageSet {
pub id: String,
pub index: Option<i32>,
pub total: Option<i32>,
}Fields
id: StringImage set ID. Only included when multiple images are sent simultaneously.
index: Option<i32>An index starting from 1, indicating the image number in a set of images sent simultaneously. Only included when multiple images are sent simultaneously. However, it won’t be included if the sender is using LINE 11.15 or earlier for Android.
total: Option<i32>The total number of images sent simultaneously.
Implementations