pub struct JoinEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
}Expand description
JoinEvent : Event object for when your LINE Official Account joins a group chat or multi-person chat. You can reply to join events.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
Implementations