pub struct LeaveEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
}Expand description
LeaveEvent : Event object for when a user removes your LINE Official Account from a group chat or when your LINE Official Account leaves a group chat or multi-person chat.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>Implementations
Sourceimpl LeaveEvent
impl LeaveEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
) -> LeaveEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, ) -> LeaveEvent
Event object for when a user removes your LINE Official Account from a group chat or when your LINE Official Account leaves a group chat or multi-person chat.