pub struct MemberJoinedEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
pub joined: Box<JoinedMembers>,
}Expand description
MemberJoinedEvent : Event object for when a user joins a group chat or multi-person chat that the LINE Official Account is in.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
joined: Box<JoinedMembers>Implementations
Sourceimpl MemberJoinedEvent
impl MemberJoinedEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
reply_token: String,
joined: JoinedMembers,
) -> MemberJoinedEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, reply_token: String, joined: JoinedMembers, ) -> MemberJoinedEvent
Event object for when a user joins a group chat or multi-person chat that the LINE Official Account is in.