MemberLeftEvent

Struct MemberLeftEvent 

pub struct MemberLeftEvent {
    pub type: Option<String>,
    pub source: Option<Box<Source>>,
    pub timestamp: i64,
    pub mode: EventMode,
    pub webhook_event_id: String,
    pub delivery_context: Box<DeliveryContext>,
    pub left: Box<LeftMembers>,
}
MemberLeftEvent : Event object for when a user leaves a group chat or multi-person chat that the LINE Official Account is in.

Fields

type: Option<String>

Type of the event

source: Option<Box<Source>>timestamp: i64

Time of the event in milliseconds.

mode: EventModewebhook_event_id: String

Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.

delivery_context: Box<DeliveryContext>left: Box<LeftMembers>

Implementations

Source

impl MemberLeftEvent

pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, left: LeftMembers, ) -> MemberLeftEvent

Event object for when a user leaves a group chat or multi-person chat that the LINE Official Account is in.