pub struct ModuleEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub module: Box<ModuleContent>,
}Expand description
ModuleEvent : This event indicates that the module channel has been attached to the LINE Official Account. Sent to the webhook URL server of the module channel.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>module: Box<ModuleContent>Implementations
Sourceimpl ModuleEvent
impl ModuleEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
module: ModuleContent,
) -> ModuleEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, module: ModuleContent, ) -> ModuleEvent
This event indicates that the module channel has been attached to the LINE Official Account. Sent to the webhook URL server of the module channel.