pub struct PnpDelivery {
pub data: String,
}Expand description
PnpDelivery : A delivery object containing a hashed phone number string or a string specified by X-Line-Delivery-Tag header
Fields
data: StringA hashed phone number string or a string specified by X-Line-Delivery-Tag header
Implementations
Sourceimpl PnpDelivery
impl PnpDelivery
Sourcepub fn new(data: String) -> PnpDelivery
pub fn new(data: String) -> PnpDelivery
A delivery object containing a hashed phone number string or a string specified by X-Line-Delivery-Tag header