pub struct PostbackEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: Option<String>,
pub postback: Box<PostbackContent>,
}Expand description
PostbackEvent : Event object for when a user performs a postback action which initiates a postback. You can reply to postback events.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: Option<String>Reply token used to send reply message to this event
postback: Box<PostbackContent>Implementations
Sourceimpl PostbackEvent
impl PostbackEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
postback: PostbackContent,
) -> PostbackEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, postback: PostbackContent, ) -> PostbackEvent
Event object for when a user performs a postback action which initiates a postback. You can reply to postback events.