pub struct ScenarioResult {
pub scenario_id: Option<String>,
pub revision: Option<i32>,
pub start_time: i64,
pub end_time: i64,
pub result_code: String,
pub action_results: Option<Vec<ActionResult>>,
pub ble_notification_payload: Option<String>,
pub error_reason: Option<String>,
}Fields
scenario_id: Option<String>Scenario ID executed
revision: Option<i32>Revision number of the scenario set containing the executed scenario
start_time: i64Timestamp for when execution of scenario action started (milliseconds, LINE app time)
end_time: i64Timestamp for when execution of scenario was completed (milliseconds, LINE app time)
result_code: StringScenario execution completion status
action_results: Option<Vec<ActionResult>>Execution result of individual operations specified in action. Only included when things.result.resultCode is success.
ble_notification_payload: Option<String>Data contained in notification.
error_reason: Option<String>Error reason.
Implementations