pub struct StickerMessageContent {
pub type: Option<String>,
pub id: String,
pub package_id: String,
pub sticker_id: String,
pub sticker_resource_type: StickerResourceType,
pub keywords: Option<Vec<String>>,
pub text: Option<String>,
pub quote_token: String,
pub quoted_message_id: Option<String>,
}Fields
type: Option<String>Type
id: StringMessage ID
package_id: StringPackage ID
sticker_id: StringSticker ID
sticker_resource_type: StickerResourceTypekeywords: Option<Vec<String>>Array of up to 15 keywords describing the sticker. If a sticker has 16 or more keywords, a random selection of 15 keywords will be returned. The keyword selection is random for each event, so different keywords may be returned for the same sticker.
text: Option<String>Any text entered by the user. This property is only included for message stickers. Max character limit: 100
quote_token: StringQuote token to quote this message.
quoted_message_id: Option<String>Message ID of a quoted message. Only included when the received message quotes a past message.
Implementations
Sourceimpl StickerMessageContent
impl StickerMessageContent
pub fn new( type: String, id: String, package_id: String, sticker_id: String, sticker_resource_type: StickerResourceType, quote_token: String, ) -> StickerMessageContent