pub struct TextMessageContent {
pub type: Option<String>,
pub id: String,
pub text: String,
pub emojis: Option<Vec<Emoji>>,
pub mention: Option<Box<Mention>>,
pub quote_token: String,
pub quoted_message_id: Option<String>,
}Fields
type: Option<String>Type
id: StringMessage ID
text: StringMessage text.
emojis: Option<Vec<Emoji>>Array of one or more LINE emoji objects. Only included in the message event when the text property contains a LINE emoji.
mention: Option<Box<Mention>>quote_token: StringQuote token to quote this message.
quoted_message_id: Option<String>Message ID of a quoted message. Only included when the received message quotes a past message.
Implementations