pub struct ThingsEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
pub things: Box<ThingsContent>,
}Expand description
ThingsEvent : Indicates that a user linked a device with LINE.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
things: Box<ThingsContent>Implementations
Sourceimpl ThingsEvent
impl ThingsEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
reply_token: String,
things: ThingsContent,
) -> ThingsEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, reply_token: String, things: ThingsContent, ) -> ThingsEvent
Indicates that a user linked a device with LINE.