pub struct UnsendEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub unsend: Box<UnsendDetail>,
}Expand description
UnsendEvent : Event object for when the user unsends a message.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>unsend: Box<UnsendDetail>Implementations
Sourceimpl UnsendEvent
impl UnsendEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
unsend: UnsendDetail,
) -> UnsendEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, unsend: UnsendDetail, ) -> UnsendEvent
Event object for when the user unsends a message.