pub struct UserMentionee {
pub type: Option<String>,
pub index: i32,
pub length: i32,
pub user_id: Option<String>,
pub is_self: Option<bool>,
}Expand description
UserMentionee : Mentioned target is user
Fields
type: Option<String>Mentioned target.
index: i32Index position of the user mention for a character in text, with the first character being at position 0.
length: i32The length of the text of the mentioned user. For a mention @example, 8 is the length.
user_id: Option<String>User ID of the mentioned user. Only included if mention.mentions[].type is user and the user consents to the LINE Official Account obtaining their user profile information.
is_self: Option<bool>Whether the mentioned user is the bot that receives the webhook.
Implementations
Sourceimpl UserMentionee
impl UserMentionee