pub struct VideoPlayCompleteEvent {
pub type: Option<String>,
pub source: Option<Box<Source>>,
pub timestamp: i64,
pub mode: EventMode,
pub webhook_event_id: String,
pub delivery_context: Box<DeliveryContext>,
pub reply_token: String,
pub video_play_complete: Box<VideoPlayComplete>,
}Expand description
VideoPlayCompleteEvent : Event for when a user finishes viewing a video at least once with the specified trackingId sent by the LINE Official Account.
Fields
type: Option<String>Type of the event
source: Option<Box<Source>>timestamp: i64Time of the event in milliseconds.
mode: EventModewebhook_event_id: StringWebhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
delivery_context: Box<DeliveryContext>reply_token: StringReply token used to send reply message to this event
video_play_complete: Box<VideoPlayComplete>Implementations
Sourceimpl VideoPlayCompleteEvent
impl VideoPlayCompleteEvent
Sourcepub fn new(
type: String,
timestamp: i64,
mode: EventMode,
webhook_event_id: String,
delivery_context: DeliveryContext,
reply_token: String,
video_play_complete: VideoPlayComplete,
) -> VideoPlayCompleteEvent
pub fn new( type: String, timestamp: i64, mode: EventMode, webhook_event_id: String, delivery_context: DeliveryContext, reply_token: String, video_play_complete: VideoPlayComplete, ) -> VideoPlayCompleteEvent
Event for when a user finishes viewing a video at least once with the specified trackingId sent by the LINE Official Account.